package main

import (
	"encoding/json"
	"fmt"
	"log"
	"os"
)

func main() {
	var err error

	config := loadConfig()

	//get working directory
	wd, err := os.Getwd()
	if err != nil {
		log.Fatal("couldn't find working directory", err)
	}

	curr := wd + "/curr.png"
	// apply curr.png if already preloaded
	err = hyprpaperWallpaper(curr)
	if err != nil {
		//preload curr.png if not
		err = hyprpaperPreload(curr)
		if err != nil {
			fmt.Println("could not preload (this is fine)", err)
		}
	}

	dir := config.Root + "/chsck"
	randomImg, _ := getRandomFile(dir)
	img := loadImage(randomImg)
	dst := processImage(img, config)

	saveImage("curr.png", dst)

	path := wd + "/curr.png"
	err = hyprpaperPreload(path)
	if err != nil {
		log.Fatal("preload failed!", err)
	}
	err = hyprpaperWallpaper(path)
	if err != nil {
		log.Fatal("set wallpaper failed!", err)
	}
}

func loadConfig() Config {
	configRaw, err := os.ReadFile("./config.json")
	if err != nil {
		log.Fatal("Couldn't open config file!", err)
	}

	var config Config
	err = json.Unmarshal(configRaw, &config)
	if err != nil {
		log.Fatal("Couldn't unmarshal config!", err)
	}
	return config
}
